@@ -12,13 +12,15 @@ def pattern_count(text, pattern):
         pattern ([string]): [pattern to search for in string]
 
     Returns:
-        [int]: [running tally of how many occurrences of text were found in pattern]
+        [int]: [running tally of how many occurrences of pattern were found in text]
     """
-    count = 0
-    for i in range(len(text)-len(pattern)+1):
-        if text[i:i+len(pattern)] == pattern:
-            count = count+1
-    return count
+    Count = 0
+    PatternLength = len(pattern)
+    TextLength = len(text)
+    for i in range((TextLength - PatternLength)+1):  # i represents a kmer
+        if text[i:i+PatternLength] == pattern:
+            Count += 1
+    return Count
 
 
 def frequency_map(text, k):
@@ -31,55 +33,39 @@ def frequency_map(text, k):
     Returns:
         [dict]: [for every length of kmer specified by k(keys), returns how many times it occurs in text(values)]
     """
-    freq = {}
-    n = len(text)
-    for i in range(n-k+1):
-        pattern = text[i:i+k]
-        freq[pattern] = 0
-        for j in range(n-k+1):
-            if text[j:j+k] == pattern:
-                freq[pattern] = freq[pattern] + 1
-    return freq
+    Freq = {}
+    TextLength = len(text)
+    for i in range(TextLength-k+1):  # range over all possible kmer combinations
+        Pattern = text[i:i+k]
+        Freq[Pattern] = 0
+        for j in range(TextLength-k+1):
+            if text[j:j+k] == Pattern:
+                Freq[Pattern] += 1
+    return Freq
 
 
 def frequent_words(text, k):
-    """[list of all keys that have value in freq == k]
+    """[list of all keys that have value in frequency map == k]
 
-    Dependancies: 
-        frequency Map
+    Dependancies:
+        frequency map
 
     Args:
         text ([string]): [input string]
         k ([int]): [standard for values returned by frequency map; equal valued kmers are sought out]
 
     Returns:
-        [list]: [when kmer from frequency map occurs as many times as specified k in this function, it is appended to the returned list]
+        [list]: [when kmer from frequency map (the key's value) occurs as many times as specified k in this function, 
+        it is appended to the returned list]
     """
-    words = []
-    freq = frequency_map(text, k)
-    m = max(freq.values())
-    for key in freq:
-        if freq[key] == m:
-            pattern = key
-            words.append(pattern)
-    return words
-
-
-def reverse_compliment(pattern):
-    """[finds the complement strand of a DNA strand]
-
-    Dependancies: 
-        reverse, compliment
-    Args:
-        pattern ([string]): [string of DNA to be used to find the reverse compliment]
-
-    Returns:
-        [string]: [pattern has been reversed and the complimentary base replaces the current one in string pattern]
-    """
-    pattern = reverse(pattern)  # reverse all letters in a string
-    pattern = compliment(pattern)  # complement each letter in a string
-    return pattern
-    # OR return(pattern[::-1].replace("A","t").replace("T","a").replace("G","c").replace("C","g").upper())
+    Words = []
+    Freq = frequency_map(text, k)
+    MaxFreqKey = max(Freq.values())
+    for kmer in Freq:
+        if Freq[kmer] == MaxFreqKey:
+            pattern = kmer
+            Words.append(pattern)
+    return Words
 
 
 def reverse(pattern):
@@ -91,8 +77,7 @@ def reverse(pattern):
     Returns:
         [string]: [reversed version of inputted string "pattern"]
     """
-    rev = ''.join(reversed(pattern))
-    return rev
+    return ''.join(reversed(pattern))
     # OR return pattern[::-1]
 
 
@@ -105,11 +90,29 @@ def compliment(pattern):
     Returns:
         [string]: [compliment of DNA pattern: A -> T, G -> C, T -> A, C -> G]
     """
-    basepairs = {"A": "T", "G": "C", "T": "A", "C": "G"}
-    complement = ""
+    Basepairs = {"A": "T", "G": "C", "T": "A", "C": "G"}
+    Complement = ""
     for base in pattern:
-        complement += basepairs.get(base)  # Get returns value for key
-    return complement
+        # Get returns a key's value. eg: if base = "A", get will find the key "A" and return its value, "T"
+        Complement += Basepairs.get(base)
+    return Complement
+
+
+def reverse_compliment(pattern):
+    """[finds the complement strand of a DNA strand]
+
+    Dependancies:
+        reverse, compliment
+    Args:
+        pattern ([string]): [string of DNA to be used to find the reverse compliment]
+
+    Returns:
+        [string]: [pattern has been reversed and the complimentary base replaces the current one in string pattern]
+    """
+    pattern = reverse(pattern)  # reverse all letters in a string
+    pattern = compliment(pattern)  # compliment each letter in a string
+    return pattern
+    # OR return(pattern[::-1].replace("A","t").replace("T","a").replace("G","c").replace("C","g").upper())
 
 
 def pattern_matching(pattern, genome):
@@ -122,11 +125,13 @@ def pattern_matching(pattern, genome):
     Returns:
         [list]: [returns location where text "pattern" is found in text "genome"]
     """
-    positions = []
-    for i in range(len(genome)-len(pattern)+1):
-        if pattern == genome[i:i+len(pattern)]:
-            positions.append(i)
-    return positions
+    Positions = []
+    GenomeLength = len(genome)
+    PatternLength = len(pattern)
+    for i in range(GenomeLength - PatternLength + 1):
+        if pattern == genome[i:i+PatternLength]:
+            Positions.append(i)
+    return Positions
 
 # -------------------------------------------------------------------------
 
@@ -154,25 +159,26 @@ def symbol_array(genome, symbol):
         symbol ([string]): [whichever nucleotide base to be searched for, ATGC]
 
     Returns:
-        [dict]: [symbol array of genome corresponding to symbol]
+        [dict]: [symbol array of genome corresponding to symbol.  the i-th element of the symbol array is the number of
+        occurrences of symbol in window length len(genome)//2 starting as pos i of Extendedgenome]
     """
-    array = {}
-    n = len(genome)
-    Extendedgenome = genome + genome[0:n//2]
+    SymbolArray = {}
+    GenomeLength = len(genome)
+    Extendedgenome = genome + genome[0:GenomeLength//2]  # copied to the end of the genome string
 
     # look at the first half of genome to compute first array value
-    array[0] = pattern_count(symbol, genome[0:n//2])
+    SymbolArray[0] = pattern_count(symbol, genome[0:GenomeLength//2])
 
-    for i in range(1, n):
+    for i in range(1, GenomeLength):
         # start by setting the current array value equal to the previous array value
-        array[i] = array[i-1]
+        SymbolArray[i] = SymbolArray[i-1]
 
         # the current array value can differ from the previous array value by at most 1
         if Extendedgenome[i-1] == symbol:
-            array[i] = array[i]-1
-        if Extendedgenome[i+(n//2)-1] == symbol:
-            array[i] = array[i]+1
-    return array
+            SymbolArray[i] = SymbolArray[i]-1
+        if Extendedgenome[i+(GenomeLength//2)-1] == symbol:
+            SymbolArray[i] = SymbolArray[i]+1
+    return SymbolArray
 
 
 def skew_array(genome):
@@ -205,22 +211,24 @@ def minimum_skew(genome):
         genome ([string]): [string to be parsed]
 
     Returns:
-        [list]: [wherever skew diagram obtains a minimum, it is appended to the list]
+        [list]: [. All integers i minimizing Skew[i] among all values of i from 0 to len(genome)
+        wherever skew diagram obtains a minimum, it is appended to the list]
     """
-    positions = []
-    array = skew_array(genome)
-    positions = []
+    Positions = []
+    SkewArray = skew_array(genome)
     count = 0
-    minarray = min(array)
-    for i in array:
-        if i == minarray:
-            positions.append(count)
+    MinArray = min(SkewArray)
+    for i in SkewArray:
+        if i == MinArray:
+            Positions.append(count)
         count += 1
-    return positions
+    return Positions
 
 
 def hamming_distance(p, q):
-    """[Total no. of mismatches bt strings p and q, pos i in kmers p and q is a mismatch if the symbols at pos i of the 2 strings are not the same]
+    """[Total no. of mismatches bt strings p and q, pos i in kmers p and q is a mismatch
+        if the symbols at pos i of the 2 strings are not the same. NOTE: MUST BE EQUAL LENGTH STRINGS.
+        IF NOT EQUAL LENGTH, USE LEVENSHTEIN DISTANCE]
 
     Args:
         p ([string]): [first reference string]
@@ -229,11 +237,11 @@ def hamming_distance(p, q):
     Returns:
         [int]: [number of mismatches at every point along strings p[i] and q[i]]
     """
-    count = 0
+    Count = 0
     for x, y in zip(p, q):
         if x != y:
-            count += 1
-    return count
+            Count += 1
+    return Count
 
 
 def approx_pattern_match(text, pattern, d):
@@ -250,11 +258,11 @@ def approx_pattern_match(text, pattern, d):
     Returns:
         [list]: [positions that pattern are located in text with at most d mismatches in that relationship]
     """
-    positions = []
+    Positions = []
     for i in range(len(text)-len(pattern)+1):
         if hamming_distance(text[i:i+len(pattern)], pattern) <= d:
-            positions.append(i)
-    return positions
+            Positions.append(i)
+    return Positions
 
 
 def approx_pattern_count(pattern, text, d):
@@ -266,13 +274,14 @@ def approx_pattern_count(pattern, text, d):
         d ([int]): [how many mismatches are permitted]
 
     Returns:
-        [int]: [frequent kmers with at most d mismatches]
+        [int]: [frequent kmers with at most d mismatches indicating the likely presence of a DnaA box to initiate
+        Dna replication]
     """
-    count = 0  # initialize count variable
+    Count = 0  # initialize Count variable
     for i in range(len(text)-len(pattern)+1):
         if hamming_distance(pattern, text[i:i+len(pattern)]) <= d:
-            count += 1
-    return count
+            Count += 1
+    return Count
 
 # -------------------------------------------------------------------------
 
@@ -286,25 +295,25 @@ def count(Motifs):
     Returns:
         [dict]: [lists of int with nucleotids as keys]
     """
-    count = {}
-    k = len(Motifs[0])
+    CountArray = {}
+    MotifLength = len(Motifs[0])
     for symbol in 'ACGT':
-        count[symbol] = []
-        for j in range(k):
-            count[symbol].append(0)
+        CountArray[symbol] = []
+        for j in range(MotifLength):
+            CountArray[symbol].append(0)
     t = len(Motifs)
     for i in range(t):
-        for j in range(k):
+        for j in range(MotifLength):
             symbol = Motifs[i][j]
-            count[symbol][j] += 1
-    return count
+            CountArray[symbol][j] += 1
+    return CountArray
 
 
 def profile(Motifs):
     """[frequency of i-th nucleotide in the j-th column of the Motif matrix]
 
     Dependancies:
-        count 
+        count
 
     Args:
         Motifs ([string matrix]): [holds several DNA strings as kmers - motifs]
@@ -312,12 +321,12 @@ def profile(Motifs):
     Returns:
         [dict]: [all elements of count matrix divided by the number of rows in motifs]
     """
-    profile = count(Motifs)
-    t = len(Motifs)
-    for letter, values in profile.items():
-        new_vals = [v / t for v in values]
-        profile[letter] = new_vals
-    return profile
+    ProfileArray = count(Motifs)
+    MotifLength = len(Motifs)
+    for letter, values in ProfileArray.items():
+        new_vals = [v / MotifLength for v in values]
+        ProfileArray[letter] = new_vals
+    return ProfileArray
 
 
 def consensus(Motifs):
@@ -332,18 +341,18 @@ def consensus(Motifs):
     Returns:
         [string]: [most popular nucleotides in each column of motif matrix. If Motifs seen correctly from collection of upstream regions, consensus provides a candidate regulatory motif for these regions]
     """
-    k = len(Motifs[0])
+    MotifLength = len(Motifs[0])
     Count = count(Motifs)
-    consensus = ""
-    for j in range(k):
-        m = 0
-        frequentSymbol = ""
+    Consensus = ""
+    for j in range(MotifLength):
+        MostPopular = 0  # Initialize the most popular nucleotide base as a reference
+        FrequentSymbols = ""
         for symbol in "ACGT":
-            if Count[symbol][j] > m:
-                m = Count[symbol][j]
-                frequentSymbol = symbol
-        consensus += frequentSymbol
-    return consensus
+            if Count[symbol][j] > MostPopular:
+                MostPopular = Count[symbol][j]
+                FrequentSymbols = symbol
+        Consensus += FrequentSymbols
+    return Consensus
 
 
 def score(Motifs):
@@ -360,12 +369,12 @@ def score(Motifs):
     """
     Count = count(Motifs)
     Consensus = consensus(Motifs)
-    letters = {'A', 'C', 'T', 'G'}
+    Letters = {'A', 'C', 'T', 'G'}
     running_sum = 0
     for i, letter in enumerate(Consensus):
-        losers = letters - set(letter)
-        for remaining_letter in losers:
-            running_sum += Count[remaining_letter][i]
+        UnpopularLetter = Letters - set(letter)
+        for RemainingLetter in UnpopularLetter:
+            running_sum += Count[RemainingLetter][i]
     return running_sum
 
 
@@ -401,15 +410,15 @@ def profile_most_probable_kmer(text, k, profile):
     Returns:
         [string]: [kmer that has the highest probability of being generated]
     """
-    n = len(text)
-    m = 0
+    TextLength = len(text)
+    CurrentProbability = 0
     x = text[1:k]
-    for i in range(n-k+1):
-        pattern = text[i:i+k]
-        p = probability_kmer(pattern, profile)
-        if p > m:
-            m = p
-            x = pattern
+    for i in range(TextLength-k+1):
+        Pattern = text[i:i+k]
+        MostProbableKmer = probability_kmer(text, profile)
+        if MostProbableKmer > CurrentProbability:
+            CurrentProbability = MostProbableKmer
+            x = Pattern
     return x
 
 
@@ -423,9 +432,9 @@ def entropy(nucleotide, probability):
     Returns
         [int]: [represents conservation of the column. lower entropy is better as it means probability distribution is most likely to occur]
     """
-    prob_dist = zip(nucleotide, probability)
+    ProbabilityDistribution = zip(nucleotide, probability)
     H = 0
-    for j in prob_dist:
+    for j in ProbabilityDistribution:
         for i in j:
             H = H + i*(math.log(i, 2))
 
@@ -443,18 +452,18 @@ def count_with_pseudocounts(Motifs):
     Returns:
         [dict]: [count matrix of Motifs with pseudocounts as a dict of lists]
     """
-    count = {}
-    k = len(Motifs[0])
+    Count = {}
+    MotifLength = len(Motifs[0])
     for symbol in "ACGT":
-        count[symbol] = []
-        for j in range(k):
-            count[symbol].append(1)
-    t = len(Motifs)
-    for i in range(t):
-        for j in range(k):
+        Count[symbol] = []
+        for j in range(MotifLength):
+            Count[symbol].append(1)
+    FullMotifLength = len(Motifs)
+    for i in range(FullMotifLength):
+        for j in range(MotifLength):
             symbol = Motifs[i][j]
-            count[symbol][j] += 1
-    return count
+            Count[symbol][j] += 1
+    return Count
 
 
 def profile_with_pseudocounts(Motifs):
@@ -466,15 +475,15 @@ def profile_with_pseudocounts(Motifs):
     Returns:
         [dict]: [profile matrix of Motifs with pseudocount as a dict of lists]
     """
-    k = len(Motifs[0])
-    profile = {}
-    count = count_with_pseudocounts(Motifs)
+    #MotifLength = len(Motifs[0])
+    Profile = {}
+    Count = count_with_pseudocounts(Motifs)
     total = 0
     for symbol in "ACGT":
-        total += count[symbol][0]
-        for k, v in count.items():
-            profile[k] = [x/total for x in v]
-    return profile
+        total += Count[symbol][0]
+        for k, v in Count.items():
+            Profile[k] = [x/total for x in v]
+    return Profile
 
 
 def greedy_motif_with_pseudocounts(Dna, k, t):
@@ -496,8 +505,8 @@ def greedy_motif_with_pseudocounts(Dna, k, t):
     BestMotifs = []
     for i in range(t):
         BestMotifs.append(Dna[i][:k])
-    n = len(Dna[0])
-    for _ in range(n-k+1):
+    DnaLengthInitial = len(Dna[0])
+    for _ in range(DnaLengthInitial-k+1):
         Motifs = []
         Motifs.append(Dna[0][i:i+k])
         for j in range(1, t):
@@ -522,9 +531,9 @@ def motifs(profile, Dna):
         [type]: [description]
     """
     Motifs = []
-    t = len(Dna)
+    DnaLength = len(Dna)
     k = 4
-    for i in range(t):
+    for i in range(DnaLength):
         motif = profile_most_probable_kmer(Dna[i], k, profile)
         Motifs.append(motif)
     return motifs
@@ -541,19 +550,19 @@ def random_motifs(Dna, k, t):
     Returns:
         [list]: [lowest scoring motifs which would represent the most conservative ones.]
     """
-    t = len(Dna)
-    l = len(Dna[0])
+    DnaLength = len(Dna)
+    DnaLengthInitial = len(Dna[0])
     RandomMotif = []
-    for i in range(t):
-        r = random.randint(0, l-k)
-        RandomMotif.append(Dna[i][r:r+k])
+    for i in range(DnaLength):
+        RandomKmer = random.randint(0, DnaLengthInitial-k)
+        RandomMotif.append(Dna[i][RandomKmer:RandomKmer+k])
     return RandomMotif
 
 
 def random_motif_search(Dna, k, t):
     """[starts by generating a collection of random motifs using the random_motifs function which we set as the best scoring collection of motifs. It continuously runs until motif score stops improving.]
 
-    Dependancies: 
+    Dependancies:
         random_motifs, profile_with_pseudocounts, Motifs, score
 
     Args:
@@ -568,8 +577,8 @@ def random_motif_search(Dna, k, t):
     BestMotifs = M
 
     while True:
-        profile = profile_with_pseudocounts(M)
-        M = motifs(profile, Dna)
+        Profile = profile_with_pseudocounts(M)
+        M = motifs(Profile, Dna)
         if score(M) < score(BestMotifs):
             BestMotifs = M
         else:
@@ -610,9 +619,9 @@ def normalize(Probabilities):
     Returns:
         [dict]: [original keys with values rescaled so they sum to 1]
     """
-    sumd = sum(Probabilities.values())
+    SumKmerProbability = sum(Probabilities.values())
     for key in Probabilities.keys():
-        Probabilities[key] /= sumd
+        Probabilities[key] /= SumKmerProbability
     return Probabilities
 
 
@@ -627,10 +636,10 @@ def weighted_die(Probabilities):
     """
     kmer = ''  # output variable
     num = random.uniform(0, 1)
-    sumd = 0
+    SumKmerProbability = 0
     for key in Probabilities.keys():
-        sumd += Probabilities[key]
-        if num < sumd:
+        SumKmerProbability += Probabilities[key]
+        if num < SumKmerProbability:
             kmer = key
             break
     return kmer
@@ -650,9 +659,9 @@ def profile_generated_string(text, profile, k):
     Returns:
         [string]: [randomly generated kmer from text whose probabilities are generated from profile]
     """
-    n = len(text)
+    TextLength = len(text)
     probabilities = {}
-    for i in range(n-k+1):
+    for i in range(TextLength-k+1):
         probabilities[text[i:i+k]] = probability_kmer(text[i:i+k], profile)
     probabilities = normalize(probabilities)
     return weighted_die(probabilities)
@@ -679,11 +688,11 @@ def gibbs_sampler(Dna, k, t, N):
     BestMotifs = Motifs
     for _ in range(N):
         i = random.randint(0, t-1)
-        new_Motif = []
+        NewMotif = []
         for k1 in range(t):
             if k1 != i:
-                new_Motif.append(Motifs[k1])
-        profile = profile_with_pseudocounts(new_Motif)
+                NewMotif.append(Motifs[k1])
+        profile = profile_with_pseudocounts(NewMotif)
         motif_i = profile_generated_string(Dna[i], profile, k)
         Motifs[i] = motif_i
         if score(Motifs) < score(BestMotifs):
@@ -694,7 +703,7 @@ def gibbs_sampler(Dna, k, t, N):
 
 
 def list_to_string(mylist):
-    """[# A simple function to convert a list of values to a string of values with no separators
+    """[ A simple function to convert a list of values to a string of values with no separators
 ]
 
     Args:
@@ -718,13 +727,13 @@ def find_clumps(genome, k, L, t):
         t ([int]): [occurrence expected in genome - clump expected to be found at least 't' times]
     """
     # k is len of k-mer/DnaA box, L is length of genome, t is occurence
-    count = {}
+    Count = {}
     for i in range(L):
         pattern = genome[i:i+k]
         if (pattern_count(genome, pattern) == t):
-            count[pattern] = pattern_count(genome, pattern)
-    print(" ".join(count.keys()))
-    return count
+            Count[pattern] = pattern_count(genome, pattern)
+    print(" ".join(Count.keys()))
+    return Count
 
 
 def permute_motif_once(motif, alphabet={"A", "C", "G", "T"}):
@@ -732,7 +741,7 @@ def permute_motif_once(motif, alphabet={"A", "C", "G", "T"}):
     Gets all strings within hamming distance 1 of motif and returns it as a
     list.
     """
-
+    #online solution
     return list(set(itertools.chain.from_iterable([[
         motif[:pos] + nucleotide + motif[pos + 1:] for
         nucleotide in alphabet] for
@@ -740,10 +749,10 @@ def permute_motif_once(motif, alphabet={"A", "C", "G", "T"}):
 
 
 def permute_motif_distance_times(motif, d):
-    workingSet = {motif}
+    WorkingSet = {motif}
     for _ in range(d):
-        workingSet = set(itertools.chain.from_iterable(map(permute_motif_once, workingSet)))
-    return list(workingSet)
+        WorkingSet = set(itertools.chain.from_iterable(map(permute_motif_once, WorkingSet)))
+    return list(WorkingSet)
 
 
 def freq_words_mismatch(Genome, k, d):
@@ -761,29 +770,29 @@ def freq_words_mismatch(Genome, k, d):
     Returns:
         [list]: [most frequent kmers]
     """
-    aprox_frq_words = []
-    frequencies = defaultdict(lambda: 0)
+    ApproxFreqWords = []
+    Freqs = defaultdict(lambda: 0)
     # all existent kmers with d mismatches of current kmer in genome
     for index in range(len(Genome) - k + 1):
-        curr_kmer_and_neighbors = permute_motif_distance_times(Genome[index: index + k], d)
-        for kmer in curr_kmer_and_neighbors:
-            frequencies[kmer] += 1
+        CurrentKmerAndNeighbor = permute_motif_distance_times(Genome[index: index + k], d)
+        for kmer in CurrentKmerAndNeighbor:
+            Freqs[kmer] += 1
 
-    for kmer in frequencies:
-        if frequencies[kmer] == max(frequencies.values()):
-            aprox_frq_words.append(kmer)
-    return aprox_frq_words
+    for kmer in Freqs:
+        if Freqs[kmer] == max(Freqs.values()):
+            ApproxFreqWords.append(kmer)
+    return ApproxFreqWords
 
 
 def pattern_matching_with_mismatch(text, pat, d):
-    count = 0
+    Count = 0
     for i in range(0, len(text)):
         p = text[i:i+len(pat)]
         if len(p) != len(pat):
             break
         if hamming_distance(p, pat) <= d:
-            count = count+1
-    return count
+            Count = Count+1
+    return Count
 
 
 def pattern_to_number(pattern):
@@ -792,9 +801,9 @@ def pattern_to_number(pattern):
     SymbolToNumber = {'A': 0, 'C': 1, 'G': 2, 'T': 3}
     if len(pattern) == 1:
         return SymbolToNumber[pattern]
-    n = len(pattern)
-    symbol = pattern[n-1]
-    prefix = pattern[:n-1]
+    PatternLength = len(pattern)
+    symbol = pattern[PatternLength-1]
+    prefix = pattern[:PatternLength-1]
     return (4*pattern_to_number(prefix)+SymbolToNumber[symbol])
 
 
@@ -824,16 +833,16 @@ def mismatches_and_reverse_compliment(text, k, d):
     Returns:
         [dict]: [performs pattern matching accounting for both reverse compliments of regular and mismatches]
     """
-    frequencyarray = {}
-    rev_text = reverse_compliment(text)
+    FrequencyArray = {}
+    RevComp = reverse_compliment(text)
     for i in range(0, 4**k):
-        frequencyarray[i] = 0
-    for i in frequencyarray:
-        count, r_count = 0, 0
-        count = pattern_matching_with_mismatch(text, number_to_pattern(i, k), d)
-        r_count = pattern_matching_with_mismatch(rev_text, number_to_pattern(i, k), d)
-        frequencyarray[i] = count+r_count
-    return frequencyarray
+        FrequencyArray[i] = 0
+    for i in FrequencyArray:
+        Count, RevCount = 0, 0
+        Count = pattern_matching_with_mismatch(text, number_to_pattern(i, k), d)
+        RevCount = pattern_matching_with_mismatch(RevComp, number_to_pattern(i, k), d)
+        FrequencyArray[i] = Count+RevCount
+    return FrequencyArray
 
 
 def neighbors(Pattern, d):
@@ -862,10 +871,11 @@ def neighbors(Pattern, d):
             Neighborhood.append(Pattern[0] + Text)
     return Neighborhood
 
-#---------------------------------------------------------------------------------------
+# ---------------------------------------------------------------------------------------
+
 
 def suffix(Pattern):
-    """ 
+    """
     return every symbol in pattern except the first
     """
     if len(Pattern) == 1:
@@ -875,16 +885,17 @@ def suffix(Pattern):
 
 
 def first_symbol(Pattern):
-    """ 
+    """
     return first symbol of pattern
-    """ 
+    """
     x = Pattern[0]
     return x
 
+
 def motif_enumeration(Dna, k, d):
     """[A kmer is a k,d motif if it appears in every string
        from Dna with at most d mismatches]
-    
+
     Dependancies:
         neighbours,suffix,first_symbol,hamming_distance
 
@@ -896,29 +907,29 @@ def motif_enumeration(Dna, k, d):
     Returns:
         [string]: [Returns all (k,d)-motifs in Dna]
     """
-    patterns = set()
-    n = len(Dna)
+    Patterns = set()
+    DnaLength = len(Dna)
     AllKmers = []
-    for j in range(n):
+    for j in range(DnaLength):
         a = Dna[j]
         kmers = []
-        n_1 = len(a)
-        for i in range(n_1 - k + 1):
+        DnaLength_1 = len(a)
+        for i in range(DnaLength_1 - k + 1):
             kmers.append(a[i:i+k])
-        neigh = []
+        Neighbors = []
         for i in range(len(kmers)):
-            l = UpdateNeighbours(kmers[i], d)
+            l = neighbors(kmers[i], d)
             for val in l:
-                neigh.append(val)
-        AllKmers.append(neigh)
+                Neighbors.append(val)
+        AllKmers.append(Neighbors)
     x1 = set(AllKmers[0])
     x2 = set(AllKmers[1])
-    patterns = x1 and x2
+    Patterns = x1 and x2
     for y in range(2, len(AllKmers)):
-        patterns = patterns and set(AllKmers[y])
-    patterns = list(patterns)
+        Patterns = Patterns and set(AllKmers[y])
+    Patterns = list(Patterns)
     string = ""
-    for i in patterns:
+    for i in Patterns:
         string = string + i + " "
     return string
 
@@ -930,10 +941,11 @@ def median_string(Dna, k):
         Runtime: len(dna) * (k+ k**d) * len(dna) * k
 
     Dependancies
-        neighbors, hamming_distance
-        
+        neighbors, hamming_distance, suffix
+
     Args:
         Dna ([string]): [space separated string sequences of nucleotides]
+        Pattern ([string]): [pattern to search for in Dna string]
         k ([int]): [determines length of kmer]
 
     Returns
@@ -941,29 +953,29 @@ def median_string(Dna, k):
     """
 
     def get_distance(Pattern, Text):
-        n = len(Text)
-        k = len(Pattern)
-        min_distance = hamming_distance(Text[:k], Pattern)
-        for i in range(n - k + 1):
-            distance = hamming_distance(Text[i:i + k], Pattern)
+        TextLength = len(Text)
+        PatternLength = len(Pattern)
+        min_distance = hamming_distance(Text[:PatternLength], Pattern)
+        for i in range(TextLength - PatternLength + 1):
+            distance = hamming_distance(Text[i:i + PatternLength], Pattern)
             if distance < min_distance:
                 min_distance = distance
         return min_distance
 
     def get_total_distance(Pattern, Dna):
-        total_distance = 0
+        TotalDistance = 0
         for text in Dna:
-            distance = get_distance(Pattern, text)
-            total_distance += distance
-        return total_distance
+            Distance = get_distance(Pattern, text)
+            TotalDistance += Distance
+        return TotalDistance
 
-    min_pattern = first_symbol(Pattern)
-    min_total_distance = get_total_distance(min_pattern, Dna)
-    for pattern in Suffix(Pattern):
-        total_distance = get_total_distance(pattern, Dna)
-        if total_distance < min_total_distance:
+    min_pattern = first_symbol(Dna)
+    MinTotalDistance = get_total_distance(min_pattern, Dna)
+    for pattern in suffix(Dna):
+        TotalDistance = get_total_distance(pattern, Dna)
+        if TotalDistance < MinTotalDistance:
             min_pattern = pattern
-            min_total_distance = total_distance
+            MinTotalDistance = TotalDistance
 
     return min_pattern
 
@@ -973,7 +985,7 @@ def distance_between_pattern_and_string(Pattern, Dna):
 
     Dependancies:
         hamming_distance
-    
+
     Args:
         Pattern ([string]): [k-mer pattern reference to be searched for in Dna]
         Dna ([string]): [space separated string sequences of nucleotides]
@@ -981,16 +993,17 @@ def distance_between_pattern_and_string(Pattern, Dna):
     Returns:
         [int]: [the distance between Pattern and Dna - score]
     """
-    k = len(Pattern)
+    PatternLength = len(Pattern)
     d = 0
     for text in Dna:
         d_temp = float('Inf')
-        for i in range(len(text) - k + 1):
-            if d_temp > hamming_distance(Pattern, text[i:i+k]):
-                d_temp = hamming_distance(Pattern, text[i:i+k])
+        for i in range(len(text) - PatternLength + 1):
+            if d_temp > hamming_distance(Pattern, text[i:i+PatternLength]):
+                d_temp = hamming_distance(Pattern, text[i:i+PatternLength])
         d += d_temp
     return d
 
+
 def profile_most_probable_kmer_noPR(text, k, profile):
     """[a kmer that was most likely to have been generated by profile among all kmers in text]
 
@@ -1005,15 +1018,16 @@ def profile_most_probable_kmer_noPR(text, k, profile):
     Returns:
         [string]: [kmer that has the highest probability of being generated]
     """
-    probability = []
+    Probability = []
     for i in range(len(text)-k+1):
         compute = 1
         for j in range(k):
             compute = compute*(profile[text[i+j]][j])
-        probability.append(compute)
-    idx = probability.index(max(probability))
+        Probability.append(compute)
+    idx = Probability.index(max(Probability))
     return text[idx:idx+k]
 
+
 def greedy_motif_search(Dna, k, t):
     """[selects the most attractive candidate from the profile using profile_most_probable_kmer]
 
@@ -1028,11 +1042,11 @@ def greedy_motif_search(Dna, k, t):
     Returns:
         [list]: [A collection of strings BestMotifs]
     """
-    bestmotifs = [string[:k]for string in Dna]
+    BestMotifs = [string[:k]for string in Dna]
     for j in range(len(Dna[0])-k+1):
         motifs = [Dna[0][j:j+k]]
         for i in range(1, t):
             motifs += [profile_most_probable_kmer_noPR(Dna[i], k, profile(motifs))]
-        if score(motifs) < score(bestmotifs):
-            bestmotifs = motifs
-    return bestmotifs
\ No newline at end of file
+        if score(motifs) < score(BestMotifs):
+            BestMotifs = motifs
+    return BestMotifs
